@@ -65,7 +65,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.13.3
+		echo VERSION=9.14.3
 		exit 0
 		;;
 	--cflags)
@@ -150,7 +150,7 @@ if test x"$echo_libs" = x"true"; then
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -ljson-c  -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -licui18n -licuuc -licudata -lm -ldl -latomic"
+		libs="$libs  -ljson-c -llmdb  -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -licui18n -licuuc -licudata -lm -ldl -latomic"
 	fi
 	echo $libs
 fi
